RST examples
============

Multi-line input
----------------

.. terminal::
    :copy:
    :scroll:
    :user: author
    :host: canonical
    :dir: ~/path

    input line 1
    input line 2

    output line 1
    output line 2

    output line-3

No input
--------

.. terminal::
    :scroll:
    :user: author
    :host: canonical
    :dir: ~/path
    :output-only:

    output line 1
    output line 2

    output line 3

No output
---------

.. terminal::
    :copy:
    :scroll:
    :user: author
    :host: canonical
    :dir: ~/path

    input line 1
    input line 2
